from .nanpa import npa

# Based on E164 list from ITU mapped to ISO-3166-1 Alpha 2 by hand
# https://www.itu.int/dms_pub/itu-t/opb/sp/T-SP-E.164D-11-2011-PDF-E.pdf
# http://www.itu.int/opb/publications.aspx?parent=T-SP&view=T-SP2
mapping = {
    1: npa,
    2: {
        0: 'EG',
        1: {
            1: 'SS',
            2: 'MA',
            3: 'DZ',
            6: 'TN',
            8: 'LY',
        },
        2: {
            0: 'GM',
            1: 'SN',
            2: 'MR',
            3: 'ML',
            4: 'GN',
            5: 'CI',
            6: 'BF',
            7: 'NE',
            8: 'TG',
            9: 'BJ',
        },
        3: {
            0: 'MU',
            1: 'LR',
            2: 'SL',
            3: 'GH',
            4: 'NG',
            5: 'TD',
            6: 'CF',
            7: 'CM',
            8: 'CV',
            9: 'ST',
        },
        4: {
            0: 'GQ',
            1: 'GA',
            2: 'CG',
            3: 'CD',
            4: 'AO',
            5: 'GW',
            6: 'DG',
            7: 'SH',
            8: 'SC',
            9: 'SD',
        },
        5: {
            0: 'RW',
            1: 'ET',
            2: 'SO',
            3: 'DJ',
            4: 'KE',
            5: 'TZ',
            6: 'UG',
            7: 'BI',
            8: 'MZ',
        },
        6: {
            0: 'ZM',
            1: 'MG',
            2: 'RE',  # TODO: Should implement ARCEP (French NPA)
            3: 'ZW',
            4: 'NA',
            5: 'MW',
            6: 'LS',
            7: 'BW',
            8: 'SZ',
            9: 'KM',
        },
        7: 'ZA',
        9: {
            0: 'SH',
            1: 'ER',
            7: 'AW',
            8: 'FO',
            9: 'GL',
        }
    },
    3: {
        0: 'GR',
        1: 'NL',
        2: 'BE',
        3: 'FR',
        4: 'ES',
        5: {
            0: 'GI',
            1: 'PT',
            2: 'LU',
            3: 'IE',
            4: 'IS',
            5: 'AL',
            6: 'MT',
            7: 'CY',
            8: 'FI',
            9: 'BG',
        },
        6: 'HU',
        7: {
            0: 'LT',
            1: 'LV',
            2: 'EE',
            3: 'MD',
            4: 'AM',
            5: 'BY',
            6: 'AD',
            7: 'MC',
            8: 'SM',
            9: 'VA',
        },
        8: {
            0: 'UA',
            1: 'RS',
            2: 'ME',
            3: 'XK',
            5: 'HR',
            6: 'SI',
            7: 'BA',
            9: 'MK',
        },
        9: 'IT',
    },
    4: {
        0: 'RO',
        1: 'CH',
        2: {
            0: 'CZ',
            1: 'SK',
            3: 'LI',
        },
        3: 'AT',
        4: 'GB',
        5: 'DK',
        6: 'SE',
        7: 'NO',
        8: 'PL',
        9: 'DE',
    },
    5: {
        0: {
            0: 'FK',
            1: 'BZ',
            2: 'GT',
            3: 'SV',
            4: 'HN',
            5: 'NI',
            6: 'CR',
            7: 'PA',
            8: 'PM',
            9: 'HT',
        },
        1: 'PE',
        2: 'MX',
        3: 'CU',
        4: 'AR',
        5: 'BR',
        6: 'CL',
        7: 'CO',
        8: 'VE',
        9: {
            0: 'GP',
            1: 'BO',
            2: 'GY',
            3: 'EC',
            4: 'GF',
            5: 'PY',
            6: 'MQ',
            7: 'SR',
            8: 'UY',
            9: 'CW',
        },
    },
    6: {
        0: 'MY',
        1: 'AU',
        2: 'ID',
        3: 'PH',
        4: 'NZ',
        5: 'SG',
        6: 'TH',
        7: {
            0: 'TL',
            2: 'AQ',
            3: 'BN',
            4: 'NR',
            5: 'PG',
            6: 'TO',
            7: 'SB',
            8: 'VU',
            9: 'FJ',
        },
        8: {
            0: 'PW',
            1: 'WF',
            2: 'CK',
            3: 'NU',
            5: 'WS',
            6: 'KI',
            7: 'NC',
            8: 'TV',
            9: 'PF',
        },
        9: {
            0: 'TK',
            1: 'FM',
            2: 'MH',
        },
    },
    7: {
        0: 'RU',
        1: 'RU',
        2: 'RU',
        3: 'RU',
        4: 'RU',
        5: 'RU',
        6: 'RU',
        7: 'KZ',
        8: 'RU',
        9: 'RU',
    },


    8: {
        1: 'JP',
        2: 'KR',
        4: 'VN',
        5: {
            0: 'KP',
            2: 'HK',
            3: 'MO',
            5: 'KH',
            6: 'LA',
        },
        6: 'CN',
        8: {
            0: 'BD',
            6: 'TW',
        },
    },
    9: {
        0: 'TR',
        1: 'IN',
        2: 'PK',
        3: 'AF',
        4: 'LK',
        5: 'MM',
        6: {
            0: 'MV',
            1: 'LB',
            2: 'JO',
            3: 'SY',
            4: 'IQ',
            5: 'KW',
            6: 'SA',
            7: 'YE',
            8: 'OM',
        },
        7: {
            0: 'PS',
            1: 'AE',
            2: 'IL',
            3: 'BH',
            4: 'QA',
            5: 'BT',
            6: 'MN',
            7: 'NP',
        },
        8: 'IR',
        9: {
            2: 'TJ',
            3: 'TM',
            4: 'AZ',
            5: 'GE',
            6: 'KG',
            8: 'UZ',
        },
    },
}
